@@ -7,7 +7,7 @@ import random
 from glob import glob
 from .extracteur import ExtracteurDeJus
 from play_sounds import play_file
-from pathlib import Path
+from pathlib import PurePath
 directory = os.path.dirname(os.path.abspath(__file__))
 
 
@@ -19,7 +19,7 @@ class nectar(ExtracteurDeJus):
         self.failure_files = glob(os.path.join(directory, 'Sounds', 'Kaamelott', 'Echec', '*.wav'))
 
     def success(self):
-        play_file(Path(random.choice(self.success_files), encoding=None))
+        play_file(PurePath(random.choice(self.success_files)))
 
     def failure(self):
-        play_file(Path(random.choice(self.failure_files), encoding=None))
+        play_file(PurePath(random.choice(self.failure_files)))
